gen_input_map: Generate Shiny Inputs for a vector of identifiers

View source: R/shiny_inputs.R

gen_input_mapR Documentation

Generate Shiny Inputs for a vector of identifiers

Description

Generate Shiny Inputs for a vector of identifiers

Usage

gen_input_map(uid, FUN, id_prefix = NULL, ...)

Arguments

uid

a vector of unique identifiers

FUN

a ShinyInput function - should theoretically work for all shinyInput functions that have inputid as the first argument

id_prefix

a string that will be combined with the unique identifier and passed as the inputid

...

other arguments to be passed to the FUN

Value

a character vector of shinyInputs

Examples

gen_input_map(1:5, shiny::numericInput, id_prefix = "playerid_", label = "my_label", value = 1)

tanho63/tantastic documentation built on May 31, 2024, 9 p.m.