unbind_dt: Unbind Shiny Inputs (server function) When generating inputs...

View source: R/dt_unbind.R

unbind_dtR Documentation

Unbind Shiny Inputs (server function) When generating inputs reactively, it's sometimes necessary to unbind old inputs so that you can use the updated inputs in Shiny. 'unbind_dt_js() adds the JS to the UI, while unbind_dt() is called as needed in the server component (usually as part of an observeEvent or eventReactive)

Description

Unbind Shiny Inputs (server function) When generating inputs reactively, it's sometimes necessary to unbind old inputs so that you can use the updated inputs in Shiny. 'unbind_dt_js() adds the JS to the UI, while unbind_dt() is called as needed in the server component (usually as part of an observeEvent or eventReactive)

Usage

unbind_dt(dt_name, session = shiny::getDefaultReactiveDomain())

Arguments

dt_name

String representing the table's output ID (i.e. to unbind in output$table_alpha, use "table_alpha" as the parameter)

session

a shiny::session object

Value

a call to the JS that unbinds dt_name


tanho63/tantastic documentation built on May 31, 2024, 9 p.m.