View source: R/progressively.R
| progressively | R Documentation |
This function helps add progress-reporting to any function - given function f()
and progressor p(), it will return a new function that calls f() and then
(on-exiting) will call p() after every iteration. Now superseded by purrr's
map .progress arguments.
progressively(f, p = NULL)
f |
a function to add progressr functionality to. |
p |
a progressor function similar to that created by |
This is inspired by purrr's safely, quietly, and possibly function decorators.
a function that does the same as f but it calls p() after iteration.
try({
urls <- c("https://github.com/nflverse/nflverse-data/releases/download/test/combines.csv",
"https://github.com/nflverse/nflverse-data/releases/download/test/combines.csv")
read_test_files <- function(urls){
p <- progressr::progressor(along = urls)
lapply(urls, progressively(read.csv, p))
}
progressr::with_progress(read_test_files(urls))
# superseded by
purrr::map(urls, read.csv, .progress = TRUE)
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.